@@ -54,26 +54,21 @@ gst_users_tool_class_init (GstUsersToolClass *class)
 }
 
 static void
-on_showall_changed (GConfClient *client,
+on_option_changed (GConfClient *client,
 		    guint        conn_id,
 		    GConfEntry  *entry,
 		    gpointer     data)
 {
 	GstTool *tool = GST_TOOL (data);
-	GConfValue *value;
 	GtkWidget *widget;
 	GtkTreeModel *model;
 
-	value = gconf_entry_get_value (entry);
-	GST_USERS_TOOL (tool)->showall = gconf_value_get_bool (value);
+	GST_USERS_TOOL (tool)->showall = gst_conf_get_boolean (GST_TOOL (tool), "showall");
+	GST_USERS_TOOL (tool)->showroot = gst_conf_get_boolean (GST_TOOL (tool), "showroot");
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "users_table");
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
 	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (model));
-	
-	widget = gst_dialog_get_widget (tool->main_dialog, "groups_table");
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (model));
 }
 
 static void
@@ -105,9 +100,12 @@ gst_users_tool_constructor (GType                  type,
 
 	tool = GST_TOOL (object);
 	GST_USERS_TOOL (tool)->showall = gst_conf_get_boolean (GST_TOOL (tool), "showall");
+	GST_USERS_TOOL (tool)->showroot = gst_conf_get_boolean (GST_TOOL (tool), "showroot");
 
 	gst_conf_add_notify (GST_TOOL (tool), "showall",
-			     on_showall_changed, tool);
+			     on_option_changed, tool);
+	gst_conf_add_notify (GST_TOOL (tool), "showroot",
+			     on_option_changed, tool);
 
 	return object;
 }
@@ -139,7 +137,8 @@ update_users (GstUsersTool *tool)
 
 	while (valid) {
 		user = oobs_list_get (list, &iter);
-		users_table_add_user (OOBS_USER (user), &iter);
+		users_table_add_user (OOBS_USER (user));
+		gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (user));
 
 		g_object_unref (user);
 		valid = oobs_list_iter_next (list, &iter);
@@ -164,10 +163,11 @@ update_groups (GstUsersTool *tool)
 
 	while (valid) {
 		group = oobs_list_get (list, &iter);
-		groups_table_add_group (OOBS_GROUP (group), &iter);
+		groups_table_add_group (OOBS_GROUP (group));
+		gst_tool_add_configuration_object (GST_TOOL (tool), OOBS_OBJECT (group));
 
 		/* update privileges table too */
-		privileges_table_add_group (OOBS_GROUP (group), &iter);
+		privileges_table_add_group (OOBS_GROUP (group));
 
 		g_object_unref (group);
 		valid = oobs_list_iter_next (list, &iter);
